# Copyright

import os.path as _os_path

from h5config.storage.hdf5 import HDF5_Storage as _HDF5_Storage

from . import LOG as _LOG
from .afm import AFM as AFM
from .config import AFMConfig as _AFMConfig


DEFAULT_FILENAME = _os_path.expanduser(_os_path.join(
        '~', '.config', 'pyafm-default.h5'))
DEFAULT_GROUP = '/'


def save_afm(afm, filename=None, group=None):
    if filename is None:
        filename = DEFAULT_FILENAME
    if group is None:
        group = DEFAULT_GROUP
    assert group.endswith('/'), group
    _LOG.info('saving AFM config to {} {}'.format(filename, group))
    storage = _HDF5_Storage(filename=filename, group=group)
    storage.save(config=afm.config)

def load_afm(filename=None, group=None, devices=None):
    if filename is None:
        filename = DEFAULT_FILENAME
    if group is None:
        group = DEFAULT_GROUP
    assert group.endswith('/'), group
    _LOG.info('loading AFM config from {} {}'.format(filename, group))
    config = _AFMConfig(storage=_HDF5_Storage(filename=filename, group=group))
    config.load()
    _LOG.debug(
        'constructing AFM from configuration:\n{}'.format(config.dump()))
    return AFM(config=config, devices=devices)
